# -*- coding: utf-8 -*-
from __future__ import absolute_import
from .wrapper import Dictionary
from .dawgs import (DAWG, CompletionDAWG, BytesDAWG, RecordDAWG,
                    IntDAWG, IntCompletionDAWG)
